@@ -20,7 +20,9 @@ from liquid.exceptions import LiquidSyntaxError
 from liquid.loaders import DictLoader
 from liquid.parse import get_parser
 from liquid.stream import TokenStream
+
 from liquid.template import BoundTemplate
+from liquid.template import Refs
 
 from liquid.expression import Filter
 from liquid.expression import Identifier
@@ -59,7 +61,7 @@ class ParserCase(NamedTuple):
 
 class EvalCase(NamedTuple):
     description: str
-    context: Mapping
+    context: Mapping[str, Any]
     expression: str
     expect: Any
 
@@ -75,7 +77,7 @@ class RenderCase(NamedTuple):
 class IfExpressionLexerTestCase(unittest.TestCase):
     """If expression lexer test case."""
 
-    def test_lex_if_expression(self):
+    def test_lex_if_expression(self) -> None:
         """Test that we can tokenize inline `if` expressions."""
         test_cases = [
             LexerCase(
@@ -153,7 +155,7 @@ class IfExpressionLexerTestCase(unittest.TestCase):
 class IfExpressionParserTestCase(unittest.TestCase):
     """If expression parser test case."""
 
-    def test_parse_inline_if_expression(self):
+    def test_parse_inline_if_expression(self) -> None:
         """Test that we can parse inline `if` expressions."""
         test_cases = [
             ParserCase(
@@ -232,7 +234,7 @@ class IfExpressionParserTestCase(unittest.TestCase):
                 expr = parser.parse_filtered_if_expression(tokens)
                 self.assertEqual(expr, case.expect)
 
-    def test_if_expression_string(self):
+    def test_if_expression_string(self) -> None:
         """Test the string representation of an inline `if` expression."""
         tokens = TokenStream(
             tokenize_if_expression("'hello' | downcase if true else 'goodbye' | upcase")
@@ -246,7 +248,7 @@ class IfExpressionParserTestCase(unittest.TestCase):
 class IfExpressionEvalTestCase(unittest.TestCase):
     """If expression evaluation test case."""
 
-    def test_evaluate_inline_if_expression(self):
+    def test_evaluate_inline_if_expression(self) -> None:
         """Test that we correctly evaluate inline `if` expressions."""
         env = Environment()
 
@@ -313,7 +315,7 @@ class IfExpressionEvalTestCase(unittest.TestCase):
 class IfExpressionRenderTextCase(unittest.TestCase):
     """If expression render test case."""
 
-    def test_render_statement_inline_if_expression(self):
+    def test_render_statement_inline_if_expression(self) -> None:
         """Test that we correctly render output statements that use inline `if`."""
         test_cases = [
             RenderCase(
@@ -372,7 +374,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
 
         # Same again using async path.
 
-        async def coro(template):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         for case in test_cases:
@@ -385,7 +387,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
                 result = asyncio.run(coro(template))
                 self.assertEqual(result, case.expect)
 
-    def test_render_assign_inline_if_expression(self):
+    def test_render_assign_inline_if_expression(self) -> None:
         """Test that we correctly render assignment expressions that use inline `if`."""
         test_cases = [
             RenderCase(
@@ -446,7 +448,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
 
         # Same again using async path.
 
-        async def coro(template):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         for case in test_cases:
@@ -458,7 +460,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
                 result = asyncio.run(coro(template))
                 self.assertEqual(result, case.expect)
 
-    def test_render_echo_inline_if_expression(self):
+    def test_render_echo_inline_if_expression(self) -> None:
         """Test that we correctly render echo expressions that use inline `if`."""
         test_cases = [
             RenderCase(
@@ -516,7 +518,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
 
         # Same again using async path.
 
-        async def coro(template):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         for case in test_cases:
@@ -528,7 +530,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
                 result = asyncio.run(coro(template))
                 self.assertEqual(result, case.expect)
 
-    def test_unknown_filter(self):
+    def test_unknown_filter(self) -> None:
         """Test that unknown filters are handled properly."""
         env = Environment(strict_filters=True)
         env.add_tag(InlineIfStatement)
@@ -539,7 +541,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
             template.render()
 
         # and render async
-        async def coro(template: BoundTemplate):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         with self.assertRaises(NoSuchFilterFunc):
@@ -549,7 +551,7 @@ class IfExpressionRenderTextCase(unittest.TestCase):
         self.assertEqual(template.render(), "hello")
         self.assertEqual(asyncio.run(coro(template)), "hello")
 
-    def test_filter_value_error(self):
+    def test_filter_value_error(self) -> None:
         """Test unexpected filter values."""
         env = Environment()
         env.add_tag(InlineIfStatement)
@@ -559,12 +561,12 @@ class IfExpressionRenderTextCase(unittest.TestCase):
         self.assertEqual(template.render(), "")
 
         # and render async
-        async def coro(template: BoundTemplate):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         self.assertEqual(asyncio.run(coro(template)), "")
 
-    def test_filter_argument_error(self):
+    def test_filter_argument_error(self) -> None:
         """Test unexpected filter arguments."""
         env = Environment()
         env.add_tag(InlineIfStatement)
@@ -575,18 +577,18 @@ class IfExpressionRenderTextCase(unittest.TestCase):
             template.render()
 
         # and render async
-        async def coro(template: BoundTemplate):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         with self.assertRaises(FilterArgumentError):
             asyncio.run(coro(template))
 
-    def test_unexpected_filter_exception(self):
+    def test_unexpected_filter_exception(self) -> None:
         """Test unexpected filter exception."""
         env = Environment()
         env.add_tag(InlineIfStatement)
 
-        def func():
+        def func() -> None:
             raise Exception(":(")
 
         env.add_filter("func", func)
@@ -597,13 +599,13 @@ class IfExpressionRenderTextCase(unittest.TestCase):
             template.render()
 
         # and render async
-        async def coro(template: BoundTemplate):
+        async def coro(template: BoundTemplate) -> str:
             return await template.render_async()
 
         with self.assertRaises(Error):
             asyncio.run(coro(template))
 
-    def test_assign_expression_syntax_error(self):
+    def test_assign_expression_syntax_error(self) -> None:
         """Test that we handle syntax errors in `assign` expressions using inline
         `if`."""
         env = Environment()
@@ -611,3 +613,32 @@ class IfExpressionRenderTextCase(unittest.TestCase):
 
         with self.assertRaises(LiquidSyntaxError):
             env.from_string(r"{% assign foo.bar = 'hello' %}")
+
+
+class AnalyzeIfExpressionTestCase(unittest.TestCase):
+    def test_analyze_macro_tag(self) -> None:
+        """Test that we can statically analyze macro and call tags."""
+        env = Environment()
+        env.add_tag(InlineIfStatement)
+
+        template = env.from_string(r"{{ foo | upcase if a.b else bar | append: baz }}")
+
+        expected_template_globals = {
+            "foo": [("<string>", 1)],
+            "a.b": [("<string>", 1)],
+            "bar": [("<string>", 1)],
+            "baz": [("<string>", 1)],
+        }
+        expected_template_locals: Refs = {}
+        expected_refs = {
+            "foo": [("<string>", 1)],
+            "a.b": [("<string>", 1)],
+            "bar": [("<string>", 1)],
+            "baz": [("<string>", 1)],
+        }
+
+        analysis = template.analyze()
+
+        self.assertEqual(analysis.local_variables, expected_template_locals)
+        self.assertEqual(analysis.global_variables, expected_template_globals)
+        self.assertEqual(analysis.variables, expected_refs)
